import React, { useEffect, useState } from "react";
import axiosInstance from "./axiosInstance";
import { useCountry } from "@/context/CountryContext";
import { PhoneInput } from "react-international-phone";
import Button from "./Button";
export default function Form({ looking_for, modalData }) {
  const defaultCountry = useCountry();
  const [currentUrl, setCurrentUrl] = useState("");
  const [full_name, setName] = useState("");
  const [email_address, setEmail] = useState("");
  const [phone_number, setPhone] = useState("");
  const [errorMessage, setErrorMessage] = useState("");
  useEffect(() => {
    setCurrentUrl(window.location.href);
  }, []);
  const validatePhoneNumber = (number) => {
    // Adjust this regex based on the phone number format you expect
    const phoneRegex = /^\+(?:[0-9] ?){6,14}[0-9]$/;
    return phoneRegex.test(number);
  };
  const handleSubmit = async (e) => {
    e.preventDefault();

    if (!validatePhoneNumber(phone_number)) {
      setErrorMessage("Please enter a valid phone number with country code.");
      return;
    }
    // Normalize data fields
    const normalizeField = (field) =>
      field && typeof field === "object" ? Object.values(field)[0] : field;
    const data = {
      full_name: normalizeField(full_name),
      email_address: normalizeField(email_address),
      phone_number: normalizeField(phone_number),
      page_url: normalizeField(currentUrl),
      source: normalizeField("dubaigoldenvisa.co"),
      looking_for: normalizeField(looking_for),
      stage: "New Lead",
    };

    try {
      const response = await axiosInstance.post(
        `https://api.salwaproperties.com/golden-visa`,
        data
      );

      setName("");
      setEmail("");
      setPhone("");
      setErrorMessage("");
      window.location.href = "/thank-you";
    } catch (error) {
      if (error.response) {
        setErrorMessage(`Error: ${error.response.data.message}`);
      } else if (error.request) {
        setErrorMessage("No response from the server. Please try again later.");
      } else {
        setErrorMessage(
          "An error occurred while submitting the form. Please try again."
        );
      }
    }
  };
  return (
    <form onSubmit={handleSubmit}>
      <div className="mb-3">
        <div className="form-group">
          <input
            type="text"
            className="form-control"
            placeholder="Full Name"
            id="name"
            name="name"
            value={full_name}
            onChange={(e) => setName(e.target.value)}
            required
          />
        </div>
      </div>
      <div className="mb-3">
        <div className="form-group">
          <input
            type="email"
            className="form-control"
            placeholder="Email Address"
            id="email"
            name="email"
            value={email_address}
            onChange={(e) => setEmail(e.target.value)}
            required
          />
        </div>
      </div>
      <div className="mb-3">
        <div className="form-group">
          {defaultCountry ? (
            <PhoneInput
              value={phone_number}
              defaultCountry={defaultCountry}
              onChange={setPhone}
              forceDialCode
              placeholder="Phone Number"
              className="form-control"
              required
            />
          ) : null}
        </div>
      </div>
      <div className="d-flex justify-content-center">
        <Button text={"Submit"} type={"submit"} width={"50%"} />
      </div>
      {errorMessage && <p className="text-danger">{errorMessage}</p>}
    </form>
  );
}
